@@ -192,6 +192,15 @@ def artefacts(tmp_path):
             ["--device", "qemu-armv7be"],
             "qemu-armv7be.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-armv7be",
+                "--qemu-image",
+                "docker.io/linaro/tuxrun-qemu:latest",
+            ],
+            "qemu-armv7be-qemu-image.yaml",
+        ),
         (
             ["--device", "qemu-armv7be", "--prompt", "root@tuxrun"],
             "qemu-armv7be-prompt.yaml",
@@ -347,6 +356,15 @@ def artefacts(tmp_path):
             ["--device", "qemu-riscv64"],
             "qemu-riscv64.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-riscv64",
+                "--bios",
+                "https://storage.tuxboot.com/riscv64/fw_jump.elf",
+            ],
+            "qemu-riscv64-bios.yaml",
+        ),
         (
             ["--device", "qemu-sh4"],
             "qemu-sh4.yaml",
